pub struct InsertMany {
pub params: Option<Params>,
pub into: Meta<TableName>,
pub values: Values,
pub returning: Option<Returning>,
}Expand description
A bulk INSERT declaration (insert multiple rows with a single query).
Uses PostgreSQL’s UNNEST to insert multiple rows efficiently with constant SQL.
Example:
BulkCreateProducts @insert-many{
params {handle @string, status @string}
into products
values {handle, status, created_at @now}
returning {id, handle, status}
}Fields
params: Option<Params>Query parameters - each becomes an array parameter.
into: Meta<TableName>Target table.
values: ValuesValues to insert (column -> value expression). Params become UNNEST columns, other expressions are applied to each row.
returning: Option<Returning>Columns to return.