Relation

Struct Relation 

pub struct Relation {
    pub from: Option<Meta<TableName>>,
    pub where_clause: Option<Where>,
    pub order_by: Option<OrderBy>,
    pub first: Option<Meta<bool>>,
    pub fields: Option<SelectFields>,
}
A relation definition (nested query on related table).

Fields

from: Option<Meta<TableName>>

Optional explicit table name.

where_clause: Option<Where>

Filter conditions.

order_by: Option<OrderBy>

Order by clause.

first: Option<Meta<bool>>

Return only the first result.

fields: Option<SelectFields>

Fields to select from the relation.

Implementations

Source

impl Relation

pub fn table_name(&self) -> Option<&str>

Get the table name for this relation. Returns the explicit from table if set, otherwise returns None (caller should use the relation field name as fallback).

pub fn is_first(&self) -> bool

Check if this relation is a single result (first).

pub fn has_relations(&self) -> bool

Check if this relation has any nested relations.

pub fn has_vec_relations(&self) -> bool

Check if this relation has any Vec (has-many) nested relations.